/* pslSelfJobs - make condor submission file to do
 * self jobs. */
#include "common.h"
#include "portable.h"

void usage()
/* Print usage instructions and exit. */
{
errAbort(
   "pslSelfJobs - make Condor submission file to do\n"
   "psLayout jobs within bacs in a contig.\n"
   "usage:\n"
   "   pslSelfJobs ooDir output.con logDir");
}

void makeSelfJob(FILE *out, char *ooDir, char *chrom, 
	char *contig, char *logDir)
/* Add one self job to Condor output file. */
{
fprintf(out, "initialdir\t= %s/%s/%s\n", ooDir, chrom, contig);
fprintf(out, "output\t= %s/%s_%s.out\n", logDir, chrom, contig);
fprintf(out, "error\t= %s/%s_%s.err\n", logDir, chrom, contig);
fprintf(out, "queue 1\n");
fprintf(out, "\n");
}



void pslSelfJobs(char *ooDir, char *conFile, char *logDir)
/* Scan ooDir and make up a condor file to produce
 * any missing self.psl files. */
{
struct slName *chromDir, *chrom;
struct slName *contigDir, *contig;
char fileName[512];
FILE *out = mustOpen(conFile, "w");

if (mkdir(logDir, 0775) < 0)
    {
    if (errno != EEXIST)
	{
	perror("");
	errAbort("Couldn't make log directory %s", logDir);
	}
    }

fprintf(out, "# Condor submit file to create self alignments to %s\n", ooDir);
fprintf(out, "# Generated by  pslSelfJobs\n\n");
fprintf(out, "universe\t= vanilla\n");
fprintf(out, "notification\t= error\n");
fprintf(out, "requirements\t= memory > 250\n");
fprintf(out, "executable\t= /cse/guests/kent/bin/i386/psLayout\n");
fprintf(out, "log\t= %s/alllog\n", logDir);
fprintf(out, 
	"arguments\t= geno.lst geno.lst genomic /var/tmp/hg/h/10.ooc self.psl");
fprintf(out, "\n");


chromDir = listDir(ooDir, "*");
for (chrom = chromDir; chrom != NULL; chrom = chrom->next)
    {
    sprintf(fileName, "%s/%s", ooDir, chrom->name);
    contigDir = listDir(fileName, "*");
    for (contig = contigDir; contig != NULL; contig = contig->next)
	{
	sprintf(fileName, "%s/%s/%s/self.psl",
		ooDir, chrom->name, contig->name);
	if (!fileExists(fileName))
	    {
	    sprintf(fileName, "%s/%s/%s/geno.lst",
		ooDir, chrom->name, contig->name);
	    if (fileExists(fileName))
		{
		makeSelfJob(out, ooDir, chrom->name, contig->name, logDir);
		}
	    }
	}
    slFreeList(&contigDir);
    }
slFreeList(chromDir);
fclose(out);
}

int main(int argc, char *argv[])
/* Process command line. */
{
if (argc != 4)
    usage();
pslSelfJobs(argv[1], argv[2], argv[3]);
}
